Attribute VB_Name = "Module1"
' --------------------------------------------------------------
'
' Licensed Materials - Property of IBM
' "Restricted Materials of IBM"
' 5746-SM2
'   Copyright IBM Corp. 1999, 2003 All Rights Reserved.
' US Government Users Restricted Rights - Use, duplication or
' disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

' Sample API application
'
' Navigator is a sample application that exercises the eRecords
' Engine API. The TsNavigatorTree displays the file plan of an eRecordsEngine
' System using the VB "TreeView  Control" common control provided in the component
' Microsoft Windows Common Controls 6.0 (mscomctl.ocx)
'
' This application requires:
'   - VB 6 runtime
'   - msxml 3.0 parser
'   - IBM Records Manager Engine
'   - Microsoft Soap Library (if you use web services option)
'   - header handler - SoapHeaderHandler
' This application has being configured to use the web services API
'
' This application demonstrates the use of an "optimized" tree view control. When navigating
' through the file plan, each branch that is expanded is stored in the tree view  control
' as it is expanded. The tree view control requires only as much RAM as the nodes that you
' have expanded. If you close a branch the file plan components remain in memory for quick
' display the next time.
'
' When a new node is expanded, all of it's children are read in and added to the tree view
' control. If any of the children themselves have children, then a [+] sign is rendered on that
' branch to indicate to the user that the branch can be expanded.
'
' This was acccomplished by tricking the tree view control into displaying the [+] sign by adding
' a dummy node beneath the parent. The tree view control automatically displays a [+]
' sign when their are subnodes (in the tree). Once the branch is expanded for the first time, the
' dummy node is deleted and replaced with the legitimate children.
'

' ---------------------------------------------------------------------------------
Option Explicit

Global Const LISTVIEW_MODE0 = "View Large Icons"
Global Const LISTVIEW_MODE1 = "View Small Icons"
Global Const LISTVIEW_MODE2 = "View List"
Global Const LISTVIEW_MODE3 = "View Details"

' Global main form displaying tree control navigator
Public fMainForm As frmMain

' Global variables
Public intX As Integer
Public intY As Integer
Public oClientController As SoapClient30
Public oFilePlanDesignController As SoapClient30
Public oFilePlanComponentController As SoapClient30
Public blnAllowedTargets As Boolean
Public gstrHostName As String       ' Host name
Public gstrLanguageCode As String   ' Language Code
Public gstrTitle As String          ' main form title
Public gstrUserName As String       ' user login name for eRecordsEngine
Public gstrAlias As String          ' database alias
Public gstrPassword As String       ' user password for eRecordsEngine
Public gstrWSDLLocation As String   ' WSDL file location (http://... )
Public glAdd As Long
Public glAddTitle As String
Public gstrLoaded As String         ' T if branch already loaded into tree. F if not
Public gstrCompType As String       ' V - view, F - for FPC, X - dummy node
Public glID As Long                 ' ID of view or FPC
Public gstrTag As String            ' Tag value for Node. Consists of strLoaded & strCompType & ID. stored with each node loaded into tree
Public glViewID As Long             ' view id of currently expanded branch.
Public glDefinitionID As Long
Public objHeaderHandler As SoapHeaderHandler.clsHeaderHandler
Public strClientControllerKey As String
Public strFilePlanDesignControllerKey As String
Public strFilePlanComponentControllerKey As String
Private mNode As Node               ' Module-level Node variable.
Public blnClick As Boolean
Public Function getFilePlanComponentControllerKey() As String
    If strFilePlanComponentControllerKey = "" Then
       objHeaderHandler.EJBKey = strClientControllerKey
       Set oClientController.HeaderHandler = objHeaderHandler
       strFilePlanComponentControllerKey = oClientController.getFilePlanComponentControllerAsString()
    End If
    getFilePlanComponentControllerKey = strFilePlanComponentControllerKey
End Function
' used to format the "tag" string stored in a node
Public Sub SetTag(ByRef strTag As String, ByVal strLoaded As String, ByVal strCompType As String, ByVal lID As Long)
    ' e.g.    "TV29" for True, View, id 29
    
    strTag = strLoaded & strCompType & CStr(lID)
    
End Sub

' used to fetch the "tag" string stored in a node structure and deconstruct the components for
' easier manipulation
Public Sub GetTag(ByVal strTag As String, ByRef strLoaded As String, ByRef strCompType As String, ByRef lID As Long)
    strLoaded = Left(strTag, 1)
    strCompType = Mid(strTag, 2, 1)
    lID = CLng(Mid(strTag, 3))
End Sub

' Draw the initial tree consisting of all hierarchical VIEWS
Public Sub LoadViews()
    Dim objXML As New MSXML2.DOMDocument
    Dim objElement As MSXML2.IXMLDOMElement
    Dim i As Integer
    Dim strTemp As String
    Dim strXML As String
    Dim lChildCount As Long
   
    On Error GoTo errhandler
    
    Screen.MousePointer = vbHourglass
 
    Set oClientController = CreateObject("MSSOAP.SoapClient30")
    oClientController.MSSoapInit gstrWSDLLocation & "/ClientControllerEJBService.wsdl", "ClientControllerEJBService"
    
    objHeaderHandler.EJBKey = strClientControllerKey
    Set oClientController.HeaderHandler = objHeaderHandler
    
    strFilePlanDesignControllerKey = oClientController.getFilePlanDesignControllerAsString()
    objHeaderHandler.EJBKey = strFilePlanDesignControllerKey
   
    Set oFilePlanDesignController = CreateObject("MSSOAP.SoapClient30")
    oFilePlanDesignController.MSSoapInit gstrWSDLLocation & "/FilePlanDesignControllerEJBService.wsdl", "FilePlanDesignControllerEJBService"
    Set oFilePlanDesignController.HeaderHandler = objHeaderHandler
    
    strXML = oFilePlanDesignController.getFilePlanViewList(True)
    Set oFilePlanDesignController = Nothing
    
    If objXML.loadXML(strXML) Then
        
        For Each objElement In objXML.childNodes(1).childNodes
            glID = CLng(objElement.getAttribute("FlPlnViewID"))
            strTemp = "V" & CStr(glID)
    
            Set mNode = fMainForm.TreeView1.Nodes.Add("ROOT", tvwChild, strTemp, CStr(objElement.getAttribute("FlPlnViewNm")), "closed")
            SetTag gstrTag, "F", "V", glID
            mNode.Tag = gstrTag
            mNode.Sorted = True
                        
       Next objElement
    End If
    
    Screen.MousePointer = vbDefault
    
    Exit Sub
    
errhandler:
    MsgBox (Err.Description)
    

End Sub


' Main program
' Get a list of database aliases
' prompt for login information
' login and get the session id
' load the views into the tree view control
' display the tree view control

Sub Main()
    Dim fLogin As New frmLogin
    Dim oLogin As SoapClient30
    Dim oDatabase
    Dim objXML As New MSXML2.DOMDocument
    Dim objElement As MSXML2.IXMLDOMElement
    Dim strAliasName As String
    Dim strXML As String

    On Error GoTo errhandler

    ' Set up alias list
    Screen.MousePointer = vbHourglass
    On Error Resume Next
       
    Screen.MousePointer = vbDefault
    fLogin.LoginSucceeded = False
    
    fLogin.Show vbModal
    If Not fLogin.LoginSucceeded Then
        'Login Failed so exit app
        End
    End If
    
    gstrHostName = fLogin.txtHostName.Text
    gstrLanguageCode = fLogin.txtLanguageCode
    gstrUserName = fLogin.txtUserName.Text
    gstrPassword = fLogin.txtPassword.Text
    gstrAlias = fLogin.txtDatasource.Text
    gstrTitle = "TsExplorer"
    gstrWSDLLocation = fLogin.txtWSDLLocation.Text
    Screen.MousePointer = vbHourglass

    Set oLogin = CreateObject("MSSOAP.SoapClient30")
    oLogin.MSSoapInit gstrWSDLLocation & "/LoginManagerEJBService.wsdl", "LoginManagerEJBService"
    
    On Error Resume Next
    If Len(gstrHostName) = 0 Then
        gstrHostName = ""
    End If
    
    strClientControllerKey = oLogin.integrationLogin(gstrUserName, gstrPassword, gstrAlias, gstrHostName, gstrLanguageCode)
    Set objHeaderHandler = CreateObject("SoapHeaderHandler.clsHeaderHandler")
    
    If Err.Number <> 0 Then
        MsgBox (Err.Description)
        fLogin.LoginSucceeded = False
    End If
    
    Set oLogin = Nothing
    Unload fLogin

  
    Set fMainForm = New frmMain
    fMainForm.Caption = fMainForm.Caption & " [WS] "
   
    fMainForm.Caption = fMainForm.Caption & " - " & gstrUserName & "@" & gstrAlias
    fMainForm.lblConnect.Caption = "//"

    Set mNode = fMainForm.TreeView1.Nodes.Add(, , "ROOT", gstrAlias, "closed")
    
    fMainForm.TreeView1.Sorted = True
    fMainForm.TreeView1.LabelEdit = False
    fMainForm.TreeView1.LineStyle = tvwRootLines

    fMainForm.TreeView1.Sorted = True
    ' Expand top node.
     fMainForm.TreeView1.Nodes(1).Expanded = True
        

    Screen.MousePointer = vbHourglass
    LoadViews
    Screen.MousePointer = vbDefault
    
    fMainForm.Show

    Exit Sub
    
errhandler:

    MsgBox (Err.Description & ": " & Err.Number)


End Sub

Public Function getAllowedComponents(ByVal filePlanComponentID As Long)

End Function
